#include "testlib.h"
#include <iomanip>
#include <queue>

using namespace std;

typedef pair<int, int> point;
typedef array<array<char, 3>, 3> field;

void sendTurn(char role, point p) {
    cout << role << " " << (p.first + 1) << " " << (p.second + 1) << endl;
    fflush(stdout);
}

void sendAns(bool ok) {
    cout << (ok ? "OK" : "FAIL") << endl;
    fflush(stdout);
}

point readPoint(InStream &stream) {
    point p;
    p.first = stream.readInt() - 1;
    p.second = stream.readInt() - 1;
    return p;
}

point getNext(queue<point> &d, queue<point> &free, field &f) {
    while (!d.empty()) {
        auto [x, y] = d.front();
        d.pop();
        if (f[x][y] == 0) {
            return make_pair(x, y);
        }
    }
    while (!free.empty()) {
        auto [x, y] = free.front();
        free.pop();
        if (f[x][y] == 0) {
            return make_pair(x, y);
        }
    }
    throw "error";
}

void printF(field &F) {
    for (int x = 0; x < 3; ++x) {
        for (int y = 0; y < 3; ++y) {
            tout << (F[x][y] > 0 ? F[x][y] : '?');
        }
        tout << endl;
    }
}

int main(int argc, char *argv[]) {
    registerInteraction(argc, argv);

    queue<point> d1;
    queue<point> d2;

    d1.push(readPoint(inf));
    d1.push(readPoint(inf));
    d1.push(readPoint(inf));

    d2.push(readPoint(inf));
    d2.push(readPoint(inf));
    d2.push(readPoint(inf));

    queue<point> free;
    for (int i = 0; i < 9; ++i) {
        free.push(readPoint(inf));
    }

    field F;
    for (int x = 0; x < 3; ++x) {
        for (int y = 0; y < 3; ++y) {
            F[x][y] = 0;
        }
    }


    for (int i = 0; i < 3; ++i) {
        point n1 = getNext(d1, free, F);
        sendTurn('X', n1);
        F[n1.first][n1.second] = 'X';

        ouf.readToken("0");
        point p = readPoint(ouf);
        if (F[p.first][p.second] != 0) {
            sendAns(false);
            printF(F);
            quitf(_wa, "invalid 0 move (%d, %d)", p.first + 1, p.second + 1);
        }
        sendAns(true);
        F[p.first][p.second] = '0';

        point n2 = getNext(d2, free, F);
        sendTurn('#', n2);
        F[n2.first][n2.second] = '#';
    }

    printF(F);
    quitf(_ok, "ok");
}
