#include <cassert>
#include "testlib.h"
#include "random"

using ll = long long;

using namespace std;

int get(int from, int to) {
    return rnd.next(from, to);
}

static const ll max_val = 1e9, max_tests = 5'000;

struct point {
    int x, y;

    point() = default;

    point(int x_, int y_) : x(x_), y(y_) {}
};

istream &operator>>(istream &in, point &p) {
    in >> p.x >> p.y;
    return in;
}

ostream &operator<<(ostream &out, const point &p) {
    out << p.x << ' ' << p.y;
    return out;
}

bool operator==(const point &p, const pair<int, int> &d) {
    return p.x == d.first && p.y == d.second;
}

bool operator==(const point &p, const point &d) {
    return p.x == d.x && p.y == d.y;
}

bool operator!=(const point &p, const point &d) {
    return !(p == d);
}

bool rook_beat(const point &a, const point &b) {
    return a.x == b.x || a.y == b.y;
}

bool bishop_beat(const point &a, const point &b) {
    return abs(a.x - b.x) == abs(a.y - b.y);
}

struct gm {
    int n;
    int m;
    point player1;
    point player2;
    char s1;
    char s2;

    gm() = default;

    gm(int n_, int m_, point p1, point p2, char s1_, char s2_) : n(n_), m(m_), player1(p1), player2(p2), s1(s1_),
                                                                 s2(s2_) {};
};

int main(int argc, char *argv[]) {
    registerGen(argc, argv, 1);

    int n = has_opt("n") ? opt<int>("n") : -1;
    int m = has_opt("m") ? opt<int>("m") : -1;

    vector<gm> test;

    if (n != -1 && m != -1) {
        if (n <= 10 && m <= 10 && 4 * n * m * (n * m - 1) <= max_tests) {
            for (int i1 = 1; i1 <= n; i1++) {
                for (int j1 = 1; j1 <= m; j1++) {
                    for (int s1 = 0; s1 < 2; s1++) {
                        for (int i2 = 1; i2 <= n; i2++) {
                            for (int j2 = 1; j2 <= m; j2++) {
                                for (int s2 = 0; s2 < 2; s2++) {
                                    if ((i1 != i2 || j1 != j2) && !(min(n, m) == 1 && (s1 == 0 || s2 == 0))) {
                                        test.emplace_back(n, m, point(i1, j1), point(i2, j2),
                                                          (s1 ? 'R' : 'B'), (s2 ? 'R' : 'B'));
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else {
            while (test.size() < max_tests) {
                int i1 = get(1, n), j1 = get(1, m), s1 = get(0, 1);
                int i2 = get(1, n), j2 = get(1, m), s2 = get(0, 1);
                while (i1 == i2 && j1 == j2) {
                    i2 = get(1, n);
                    j2 = get(1, m);
                }
                test.emplace_back(n, m, point(i1, j1), point(i2, j2),
                                  (s1 ? 'R' : 'B'), (s2 ? 'R' : 'B'));
            }
        }
    } else {
        while (test.size() < max_tests) {
            n = get(2, max_val);
            m = get(2, max_val);
            int i1 = get(1, n), j1 = get(1, m), s1 = get(0, 1);
            int i2, j2, s2 = get(0, 1);
            if (s1) {
                if (get(0, 1)) {
                    i2 = i1;
                    j2 = get(1, m);
                    while (j2 == j1) j2 = get(1, m);
                } else {
                    j2 = j1;
                    i2 = get(1, n);
                    while (i2 == i1) i2 = get(1, n);
                }
            } else {
                if (get(0, 1)) {
                    int d = get(-min(n, m), min(n, m));
                    while (d == 0 || !(1 <= i1 + d && i1 + d <= n && 1 <= j1 + d && j1 + d <= m)) {
                        d = get(-min(n, m), min(n, m));
                    }
                    i2 = i1 + d;
                    j2 = j1 + d;
                } else {
                    int d = get(-min(n, m), min(n, m));
                    while (d == 0 || !(1 <= i1 + d && i1 + d <= n && 1 <= j1 - d && j1 - d <= m)) {
                        d = get(-min(n, m), min(n, m));
                    }
                    i2 = i1 + d;
                    j2 = j1 - d;
                }
            }
            test.emplace_back(n, m, point(i1, j1), point(i2, j2),
                              (s1 ? 'R' : 'B'), (s2 ? 'R' : 'B'));
        }
    }
    cout << test.size() << '\n';
    for (auto i: test) {
        cout << i.n << ' ' << i.m << '\n' << i.player1 << ' ' << i.s1 << '\n' << i.player2 << ' ' << i.s2 << '\n';
    }
}
