#include <iostream>
#include <cassert>
#include <vector>

using namespace std;

struct point {
    int x, y;

    point() = default;

    point(int x_, int y_) : x(x_), y(y_) {}
};

istream &operator>>(istream &in, point &p) {
    in >> p.x >> p.y;
    return in;
}

ostream &operator<<(ostream &out, const point &p) {
    out << p.x << ' ' << p.y;
    return out;
}

bool operator==(const point &p, const pair<int, int> &d) {
    return p.x == d.first && p.y == d.second;
}

bool operator==(const point &p, const point &d) {
    return p.x == d.x && p.y == d.y;
}

bool operator!=(const point &p, const point &d) {
    return !(p == d);
}

bool rook_beat(const point &a, const point &b) {
    return a.x == b.x || a.y == b.y;
}

bool bishop_beat(const point &a, const point &b) {
    return abs(a.x - b.x) == abs(a.y - b.y);
}

void win() {
    cout << "WIN";
}

void lose() {
    cout << "LOSE";
}

void draw() {
    cout << "DRAW";
}

const int maxn = 10;

struct ver {
    point player1;
    point player2;
    bool move;
    int index;

    ver() = default;

    ver(point p1, point p2, bool mov, int idx) : player1(p1), player2(p2), move(mov), index(idx) {};
};

ostream &operator<<(ostream &out, const ver &v) {
    cout << '(' << v.player1 << ") (" << v.player2 << "), " << (v.move ? "first" : "second");
    return out;
}

vector<ver> vertex;

vector<vector<int>> g;
vector<vector<int>> gr;

vector<bool> win_pos;
vector<bool> lose_pos;
vector<bool> used;
vector<int> degree;

void dfs(int v) {
    used[v] = true;
    for (auto pred: gr[v]) {
        if (!used[pred]) {
            if (lose_pos[v]) win_pos[pred] = true;
            else if (--degree[pred] == 0) {
                if (win_pos[pred]) continue;
                lose_pos[pred] = true;
            } else continue;
            dfs(pred);
        }
    }
}

int stupid_solve(int n, int m, point p1, char s1, point p2, char s2) {
    vertex.clear();
    g.clear();
    gr.clear();
    win_pos.clear();
    lose_pos.clear();
    used.clear();
    degree.clear();

    if (n >= maxn || m >= maxn) {
        int x = 0;
        while (true) {
            x++;
        }
    }

    p1.x--, p1.y--, p2.x--, p2.y--;

    for (int x1 = 0; x1 < n; x1++) {
        for (int y1 = 0; y1 < m; y1++) {
            for (int x2 = 0; x2 < n; x2++) {
                for (int y2 = 0; y2 < m; y2++) {
                    if (x1 != x2 || y1 != y2) {
                        vertex.emplace_back(point(x1, y1), point(x2, y2),
                                            false, vertex.size());
                        vertex.emplace_back(point(x1, y1), point(x2, y2),
                                            true, vertex.size());
                    }
                }
            }
        }
    }

    int sz = vertex.size();

    gr.assign(sz, {});
    g.assign(sz, {});

    for (int i = 0; i < sz; i++) {
        for (int j = 0; j < sz; j++) {
            ver from = vertex[i];
            ver to = vertex[j];
            if (from.player1 != to.player1 || from.player2 != to.player2) {
                if (from.move && !to.move && from.player2 == to.player2 &&
                    (s1 == 'R' && rook_beat(from.player1, to.player1) ||
                     s1 == 'B' && bishop_beat(from.player1, to.player1))) {
                    g[i].push_back(j);
                    gr[j].push_back(i);
                } else if (!from.move && to.move && from.player1 == to.player1 &&
                           (s2 == 'R' && rook_beat(from.player2, to.player2) ||
                            (s2 == 'B' && bishop_beat(from.player2, to.player2)))) {
                    g[i].push_back(j);
                    gr[j].push_back(i);
                }
            }
        }
    }

    win_pos.assign(sz, false);
    lose_pos.assign(sz, false);
    used.assign(sz, false);
    degree.assign(sz, 0);
    for (int i = 0; i < sz; i++) degree[i] = g[i].size();

    for (auto &cur: vertex) {
        if (rook_beat(cur.player1, cur.player2) && (s1 == 'R' && cur.move || s2 == 'R' && !cur.move) ||
            bishop_beat(cur.player1, cur.player2) && (s1 == 'B' && cur.move || s2 == 'B' && !cur.move)) {
            win_pos[cur.index] = true;
        }
    }

    for (int i = 0; i < sz; i++) {
        if ((win_pos[i] || lose_pos[i]) && !used[i]) {
            dfs(i);
        }
    }
    int x = -1;
    for (auto &cur: vertex) {
        if (cur.player1 == p1 && cur.player2 == p2 && cur.move) {
            x = cur.index;
            break;
        }
    }

    assert(x != -1);
    if (win_pos[x]) return 1;
    else if (lose_pos[x]) return 0;
    else return -1;
}

int main() {
    int tests;
    cin >> tests;
    while (tests--) {
        int n, m;
        point p1{}, p2{};
        char s1, s2;
        cin >> n >> m >> p1 >> s1 >> p2 >> s2;
        auto res = stupid_solve(n, m, p1, s1, p2, s2);
        if (res == 1) cout << "WIN";
        else if (res == 0) cout << "LOSE";
        else cout << "DRAW";
        cout << '\n';
    }
}